@@ -33,6 +33,12 @@ sub _validate_sub {
 	if ( ref $spec eq 'ARRAY' ) {
 		push @count, scalar @{$spec};
 
+		@params = $self->_preprocess_params(@params) and $count[0] = scalar @params if ( do { 
+				my $preprocess = $count[0];  
+				$_ == 0 || ! $_ % 2 ? $params[$_] =~ m/[0-9]+/ && $params[$_] <= $count[1] ? next : do { $preprocess = 0 } && last : next foreach 0 .. $count[0] - 1; 
+				$preprocess; 
+		} );
+
 		if ( $count[0] == 1 && $count[1] != 1 and ref $params[0] eq 'ARRAY' ) {
 			@params = @{ $params[0] };
 			$count[0] = scalar @params;
@@ -75,45 +81,12 @@ sub _default {
 }
 
 sub _preprocess_params {
-	my ($self, @params) = @_;
+	my ($self, %params) = @_;
 
 	my @world;
-	for my $p ( @params ) {
-		my ($ref, $index, $arg) = (ref $p);
-		! $ref and do { ($index, $arg) = $p =~ m/(\d+)=(.*)/ } && (defined $index && defined $arg)
-				? @world = _generate_params($arg, $index, @world)
-				: push @world, $p
-			or ( $ref eq 'HASH' ) and (map { $p->{$_} = [$self->_preprocess_params($p->{$_})]->[0] } keys %{$p})
-				&& push @world, $p
-			or ($ref eq 'ARRAY' ) and push @world, [ $self->_preprocess_params(@{$p}) ]
-			or push @world, $p;
-	}
+	map { $world[$_] = $params{$_} } sort keys %params;
 	return @world;
 }
 
-sub _generate_params {
-	my ($string, $index, @world, $current) = @_;
-
-	( $_ =~ m/^\s*\[\s*(.*)\]/ )
-		and do {
-			$current = [_generate_params($1)];
-			$world[$index] = $current;
-		}
-		or ( $_ =~ m/^\s*\{\s*(.*)\s*\}/ ) and do {
-			$current = {};
-			my %temp = split '=>', $1;
-			$current->{[_generate_params(($_))]->[0] } = [_generate_params($temp{$_})]->[0]
-				for keys %temp;
-			$world[$index] = $current;
-		} or (not defined $index) and do {
-			(($_ =~ m/^\s*(\d+)\s*$/) || ($_ =~ m/^\s*[\'\"]+\s*(.*?)\s*[\'\"]+\s*$/))
-				? push @world, $1 : do { $_ =~ s/^\s+|\s+$//g } && push @world, $_;
-		} or $world[$index] = $string foreach ( split /(?![^\(\[\{]+[\]\}\)]),/, $string );
-
-	return @world;
-}
-
-
-
 1;
 
